@@ -78,7 +78,7 @@ void backgrounds::on_clockset_clicked()
     ui->clockset->setDisabled(true);
     QPixmap original = clockdir;
     QSize size = QSize::QSize(800, 424);
-    QPixmap resized = original.scaled(size);
+    QPixmap resized = original.scaled(size, Qt::KeepAspectRatioByExpanding);
     resized.save("/opt/theme-customizer/clock.png");
     QStringList args;
     args << "changeimagepushed" << "clock.png";
@@ -92,7 +92,7 @@ void backgrounds::on_appmanagerset_clicked()
     ui->appmanagerset->setDisabled(true);
     QPixmap original = appdir;
     QSize size = QSize::QSize(800, 424);
-    QPixmap resized = original.scaled(size);
+    QPixmap resized = original.scaled(size, Qt::KeepAspectRatioByExpanding);
     resized.save("/opt/theme-customizer/appmanager.png");
     QStringList args;
     args << "changeimagepushed" << "appmanager.png";
@@ -106,7 +106,7 @@ void backgrounds::on_mplayerset_clicked()
     ui->mplayerset->setDisabled(true);
     QPixmap original = mdir;
     QSize size = QSize::QSize(800, 424);
-    QPixmap resized = original.scaled(size);
+    QPixmap resized = original.scaled(size, Qt::KeepAspectRatioByExpanding);
     resized.save("/opt/theme-customizer/mplayer.png");
     QStringList args;
     args << "changeimagepushed" << "mplayer.png";
@@ -120,7 +120,7 @@ void backgrounds::on_lockset_2_clicked()
     ui->lockset_2->setDisabled(true);
     QPixmap original = ldir;
     QSize size = QSize::QSize(800, 480);
-    QPixmap resized = original.scaled(size);
+    QPixmap resized = original.scaled(size, Qt::KeepAspectRatioByExpanding);
     resized.save("/opt/theme-customizer/lock.png");
     QStringList args;
     args << "changeimagepushed" << "lock.png";
